@@ -109,7 +109,8 @@ class AlleleValidator:
         [int] - all the indices of where the value was found in the array.
         None - When value can't be found in the array.
         -----------------------------------------------------------------------------------'''
-        contains = np.array([val in item for item in array])
+        # Find the exact match of the 'val'
+        contains = np.array([val in item.split('|') for item in array])
         idx_array = np.where(contains)[0]
 
         if 0 == len(idx_array): return None
@@ -560,7 +561,8 @@ class AlleleValidator:
 
         for each_synonym in synonym:
             # Find the exact match of the synonym from the synonym col
-            idx = self._get_indices(synonym_col_array, each_synonym)
+            # idx = self._get_indices(synonym_col_array, each_synonym)
+            idx = None
             if idx is None: 
                 # Try finding the synonym as a substring
                 # e.g. 'HLA-DRB5*0201' is a substring of 'HLA-DRB5*0201|DRB5*02:02'
@@ -572,14 +574,26 @@ class AlleleValidator:
                 '''
                 From Gitlab issue #743, it was requested to return itself if no
                 synonym was found.
+
+                UPDATE: From recent discussion (01/21/2025), this should return
+                None if there are no match.
+
+                UPDATE #2: This should return None if no match, but should return
+                iedblabel if user submits synonym or iedblabel.
                 '''
-                iedb_labels.append(each_synonym)
+
+                # Check if the synonym provided by the user itself is an IEDB label
+                if each_synonym in mol_df['IEDB Label'].values:
+                    iedb_labels.append(each_synonym)
+                else:
+                    iedb_labels.append(None)
+                
                 continue
         
             iedb_labels.append(mol_df.loc[idx, 'IEDB Label'])
 
         if is_input_str: iedb_labels = iedb_labels[0]
-
+        
         return iedb_labels
     
     def get_default_method_version(self, method):
@@ -923,7 +937,10 @@ class AlleleValidator:
         
         converted_allele = self.convert_synonym_to_iedblabel(allele)
         if converted_allele:
-          return "synonym"
+          if allele == converted_allele:
+            return "iedb_label"
+          else:
+            return "synonym"
         
         return "Unknown"
 
