@@ -18,8 +18,8 @@ def recursive_walk(startdir):
                 file_list.extend(sdfiles)
     return file_list
 
-pkg_data_files = ['netMHCIIpan', 'netMHCIIpan.1', 'netMHCIIpan-4.3.readme']
-os.chdir('netmhciipan_4_3_executable')
+pkg_data_files = ['netMHCIIpan', 'netMHCIIpan.1', 'NetMHCIIpan-4.1.pl', 'netMHCIIpan-4.1.readme']
+os.chdir('netmhciipan_4_1_executable')
 
 for subdir in ['data', 'Linux_x86_64', 'test']:
     file_list = recursive_walk(subdir)
@@ -30,13 +30,13 @@ with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
     README = readme.read()
 
 setup(
-    name='netmhciipan-4.3-executable',
-    version='4.3.0.0',
+    name='netmhciipan-4.1-executable',
+    version='4.1.0.1',
     author='Jason Yan',
     author_email='jyan@lji.org',
-    packages=['netmhciipan_4_3_executable'],
-    package_data={ 'netmhciipan_4_3_executable': pkg_data_files },
-    description='Python package to provide netMHCIIpan-4.3 executable',
+    packages=['netmhciipan_4_1_executable'],
+    package_data={ 'netmhciipan_4_1_executable': pkg_data_files },
+    description='Python package to provide netMHCIIpan-4.1 executable',
     long_description=README,
     install_requires=['allele-info>=3.8.0', 'iedbtools-utilities>=0.11.1'],
     keywords='T cell epitope prediction',
