@@ -159,23 +159,35 @@ def aggregate_result_file(job_desc_file, output_dir, aggregate_output_dir, has_c
 
         # iterate through the binding methods and join into the final peptide table
         for m in binding_methods:
+            print(f"m: {m}")
             #TODO: we're dropping duplicates here, but we need to understand why they are occuring in the first place
             peptide_table = all_results['peptide_table'][m].drop_duplicates()
+            print(f"peptide_table: {peptide_table.to_csv()}")
             # change allele name to iedblabel
-            peptide_table['allele'] = peptide_table['allele'].map(allele_validator.convert_synonym_to_iedblabel)
+            if 'allele' in peptide_table:
+                peptide_table['allele'] = peptide_table['allele'].map(allele_validator.convert_synonym_to_iedblabel)
             # convert scores, ic50 and percentile to float if they are not
             for field in ['ic50', 'score', 'percentile', 'adjusted_percentile']:
                 if peptide_table.get(field, None) is not None:
                     peptide_table[field] = peptide_table[field].astype('float64')
-            join_cols = ['peptide', 'allele']
+            join_cols = ['peptide']
+            # if allele is in both tables, we need to join on it
+            if 'allele' in peptide_table and 'core.' + 'allele' in final_peptide_table:
+                join_cols.append('allele')
             left_join_cols = ['core.' + x for x in join_cols]
             right_join_cols = [m + '.' + x for x in join_cols]
             ignored_cols = ['seq_num', 'start', 'end', 'peptide_length']
+            if 'seq_num' not in peptide_table:
+                ignored_cols.remove('seq_num')
             ignored_join_cols = right_join_cols + [m + '.' + x for x in ignored_cols]
+            print(f"final_peptide_table: {final_peptide_table.to_csv()}")
+            print(f"peptide_table: {peptide_table.to_csv()}")
+            print(f"left_join_cols: {left_join_cols}")
             final_peptide_table = pd.merge(final_peptide_table, peptide_table.add_prefix(m + '.'),
             left_on=left_join_cols,
             right_on=right_join_cols,
             how='left').drop(labels=ignored_join_cols, axis=1)
+            print(f"final_peptide_table: {final_peptide_table.to_csv()}")
 
         # add the median binding percentile column before the first binding-related column
         #TODO: discuss if we need median column if there's only 1 binding method
@@ -272,25 +284,32 @@ def aggregate_result_file(job_desc_file, output_dir, aggregate_output_dir, has_c
             how='left').drop(labels=ignored_join_cols, axis=1)
 
         # add the basic processing & netctlpan data
-        peptide_processing_methods = ['processing.basic_processing', 'processing.netctl', 'processing.netctlpan']
+        peptide_processing_methods = ['processing.mhciinp', 'processing.basic_processing', 'processing.netctl', 'processing.netctlpan']
         processing_methods = list(set(peptide_processing_methods) & set(all_results['peptide_table']))
         for m in processing_methods:
             #TODO: we're dropping duplicates here, but we need to understand why they are occuring in the first place
             peptide_table = all_results['peptide_table'][m].drop_duplicates()
             # sometimes the start & sequence_number columns need to be explicitly cast
             peptide_table = peptide_table.astype({'start': 'int64',
+                                                  'end': 'int64',
                                                 'sequence_number': 'int64'})
             # covert them to float if they are not
-            for field in ['tap_prediction_score', 'mhc_prediction', 'cleavage_prediction_score', 'combined_prediction_score', 'percentile_rank', 'predicted_mhc_binding_affinity', 'rescale_binding_affinity', 'c_terminal_cleavage_affinity', 'tap_transport_efficiency', 'predictions_score']:
+            for field in ['cleavage_probability_score', 'cleavage_probability_percentile_rank', 'tap_prediction_score', 'mhc_prediction', 'cleavage_prediction_score', 'combined_prediction_score', 'percentile_rank', 'predicted_mhc_binding_affinity', 'rescale_binding_affinity', 'c_terminal_cleavage_affinity', 'tap_transport_efficiency', 'predictions_score']:
                 if peptide_table.get(field, None) is not None:
                     peptide_table[field] = peptide_table[field].astype('float64')
             join_cols = ['sequence_number', 'start', 'peptide', 'allele']
+            join_cols = [col for col in join_cols if 'core.' + col in final_peptide_table.columns and col in peptide_table.columns]
+            print(f"join_cols: {join_cols}")
             left_join_cols = ['core.' + x for x in join_cols]
             right_join_cols = [m + '.' + x for x in join_cols]
+            # add processing.mhciinp.end 	processing.mhciinp.peptide_length  to drop
+            ignored_cols = ['seq_num', 'end', 'peptide_length']
+            ignored_cols = [col for col in ignored_cols if col in peptide_table.columns]
+            ignored_join_cols = right_join_cols + [m + '.' + x for x in ignored_cols]
             final_peptide_table = pd.merge(final_peptide_table, peptide_table.add_prefix(m + '.'),
             left_on=left_join_cols,
             right_on=right_join_cols,
-            how='left').drop(labels=right_join_cols, axis=1)    
+            how='left').drop(labels=ignored_join_cols, axis=1)
         # remove duplicate rows
         final_peptide_table = final_peptide_table.drop_duplicates()
         merged_results['peptide_table'] = final_peptide_table
@@ -409,9 +428,15 @@ def aggregate_result_file(job_desc_file, output_dir, aggregate_output_dir, has_c
                 merged_results[t] = merged_results[t][mask == False].reset_index(drop=True)
             if t =='peptide_table':
                 if all(col in merged_results['peptide_table'].columns for col in ['immunogenicity.cd4episcore.score', 'binding.global_median_percentile']):
+                    # add immunogenicity.cd4episcore.combined_score column but it should be next to the immunogenicity.cd4episcore.score column
+                    # immunogenicity.cd4episcore.combined_score = (0.4 * immunogenicity.cd4episcore.score) + (0.6 * binding.global_median_percentile)
+                    # round to 5 decimal places
                     a = 0.4
                     a1 = 1 - a
-                    merged_results['peptide_table']['immunogenicity.cd4episcore.combined_score'] = round((a * merged_results['peptide_table']['immunogenicity.cd4episcore.score']) + (a1 * merged_results['peptide_table']['binding.global_median_percentile']), 5)
+                    cd4episcore_combined_score = round((a * merged_results['peptide_table']['immunogenicity.cd4episcore.score']) + (a1 * merged_results['peptide_table']['binding.global_median_percentile']), 5)
+                    cd4episcore_score_index = merged_results['peptide_table'].columns.get_loc('immunogenicity.cd4episcore.score')
+                    merged_results['peptide_table'].insert(cd4episcore_score_index + 1, 'immunogenicity.cd4episcore.combined_score', cd4episcore_combined_score)
+
                     # add cd4episcore.combined_score and cd4episcore.score to pivot table
                     subset_peptide_table = merged_results['peptide_table'][['core.peptide', 'immunogenicity.cd4episcore.score', 'immunogenicity.cd4episcore.combined_score']]
                     subset_peptide_table = subset_peptide_table.drop_duplicates()
@@ -435,7 +460,9 @@ def aggregate_result_file(job_desc_file, output_dir, aggregate_output_dir, has_c
         dict_result['unique_vals'] = unique_vals
         dict_result['field_ranges'] = field_ranges
         dict_result['column_overrides'] = column_overrides
-        final_results.append(dict_result)
+        # remove empty table
+        if dict_result['table_data']:
+            final_results.append(dict_result)
 
     # add the processing plots onto the results
     if 'processing_plots' in all_results:
