@@ -46,16 +46,18 @@ methods_base_dirs = (
     'netmhciipan-4.3-executable',
     'mhcii-netmhciipan-4.3-ba-percentile-data',
     'mhcii-netmhciipan-4.3-el-percentile-data',
+    'mhcii-predictor-data',
+    'mhciinp'
 )
 for method_base_dir in methods_base_dirs:
     sys.path.append(methods_dir + '/' + method_base_dir)
 
 from mhcii_predictor_data import get_method_allele_list
 
-
 from mhcii_predictor import MhciiPredictor
 from common_bio import Proteins
 
+from mhciinp_package.mhc_ii_ligand_predictor import MHCIILigandPredict
 
 def eprint(*args, **kwargs):
     print(*args, file=sys.stderr, **kwargs)
@@ -669,6 +671,32 @@ def imm_prediction(method, sequences, names, length_list, peptide_shift=None, pe
     print("Temporary directory cleaned up.")
     return result_data
 
+def get_seq_arg_for_mhciinp(fname, seq_file_type):
+    """ Get sequence from file or string. """
+    with open(fname, 'r') as r_file:
+        sequence_text = r_file.read()
+    seq_name_list = []
+    seq_list = []
+    seq_arg = ''
+    if seq_file_type == 'fasta':
+        input_sequences = sequence_text.split(">")
+        for i in input_sequences[1:]:
+            if (len(i) > 0):
+                end_of_name = i.find("\n")
+                print(end_of_name)
+            seq_name = i[:end_of_name].rstrip()
+            seq = i[end_of_name:].split()
+            seq_name_list.append(seq_name)
+            seq_list.append(''.join(seq))
+        # Yan: ignore fasta seq name/info and use seq_num instead to be consistent with other tool
+        #for i in range(len(seq_list)):
+        #    seq_arg = seq_arg + '>' + seq_name_list[i] + '<' + seq_list[i] + '<'
+    elif seq_file_type == 'peptides':
+        seq_list = [x.strip() for x in filter(None,sequence_text.split('\n'))]
+    else:
+        raise ValueError('Invalid sequence file type: %s' % seq_file_type)
+    seq_arg = '<'.join(seq_list)
+    return seq_arg
 
 def input_data_prediction(options, args):
     """ This version takes a file containing an peptide sequences as input."""
@@ -677,7 +705,6 @@ def input_data_prediction(options, args):
 
     from mhcii_predictor import MhciiPredictor
     from common_bio import Proteins
-
     # 1. read input params
     output_prefix = options.output_prefix
     output_format = options.output_format
@@ -816,6 +843,32 @@ def input_data_prediction(options, args):
                 result = mhcnp_predict(input_allele=input_allele, lengths=lengths, fname=fname, seq_file_type=seq_file_type, output_path=output_json, **predictor)
                 print('mhcnp prediction done.')
                 return
+            elif predictor_type == 'processing' and method == 'mhciinp':
+
+                if seq_file_type not in ['fasta','peptides']:
+                    raise ValueError('can not accept seq_file_type: %s' % seq_file_type)
+                if not output_prefix:
+                    raise ValueError('Please use "-o" to specify output file prefix for method "%s"' % method)
+                # get seq_arg
+                seq_arg = get_seq_arg_for_mhciinp(fname, seq_file_type)
+                mhciinp_predict = MHCIILigandPredict()
+                mhciinp_result_df = mhciinp_predict.predict_mhciiligands(seq_arg)[1]
+                # transfer seq name to seq_num
+                mhciinp_result_df.rename(columns = {'Seq name':'sequence_number'}, inplace = True)
+                mhciinp_result_df['sequence_number'] = mhciinp_result_df['sequence_number'].str.replace('seq_', '').astype(int)
+                # transform the result to a list of tuples
+                table_columns = mhciinp_result_df.columns.tolist()
+                table_columns = [column_name.lower().strip().replace(' ', '_').replace('peptide_start', 'start').replace('peptide_end', 'end') for column_name in table_columns]
+
+                table_rows = mhciinp_result_df.values.tolist()
+                result = {
+                    "method": predictor_source,
+                    "type": "peptide_table",
+                    "table_columns": table_columns,
+                    "table_data":table_rows
+                }
+                print('mhciinp prediction done.')
+                results.append(result)
             elif predictor_type == 'binding' and method == 'mhcflurry':
                 from mhcflurry_predicter import predict as mhcflurry_predict
                 if seq_file_type not in ['fasta','peptides']:
@@ -851,6 +904,7 @@ def input_data_prediction(options, args):
                     "netmhciipan_ba-4.2":'netmhciipan_ba-4.2',
                     "netmhciipan_el-4.3":'netmhciipan_el-4.3',
                     "netmhciipan_ba-4.3":'netmhciipan_ba-4.3',
+                    "mhciinp":"mhciinp",
                 }
                 method = method_dict[method]
                 alleles = input_allele.replace('HLA-','').replace("/","-")  
@@ -1000,6 +1054,10 @@ def input_data_prediction(options, args):
         print_result(result)
     
 
+def input_validation(method, input_allele, input_length, fname, seq_file_type='peptide'):
+    return True
+    '''input validation'''
+
 
 def input_validation(method, input_allele, input_length, fname, seq_file_type='peptide'):
     '''input validation'''
