@@ -25,6 +25,7 @@ def save_json(result, output_path):
         json.dump(result, w_file, indent=2)
 
 def get_peptide_list_with_start_and_stop_and_sequencenumber(input_sequence_text, alleles, peptide_length_range='asis', peptide_spacing=1):
+    allele_validator = AlleleValidator()
     table_data = []
     sequence_list = get_sequence_list(input_sequence_text)
     if not peptide_length_range or peptide_length_range == 'asis':
@@ -35,6 +36,7 @@ def get_peptide_list_with_start_and_stop_and_sequencenumber(input_sequence_text,
     else:
         raise ValueError('if peptide_length_range not asis, peptide_shift (peptide_spacing) must be given')
     for allele in alleles:
+        allele = allele_validator.convert_synonym_to_iedblabel(allele)
         peptide_index = 1
         for seq_num, sequence in enumerate(sequence_list) :
             seq_num += 1
@@ -239,6 +241,13 @@ def split_parameters(input_data, split_inputs_dir=None):
     peptide_list = input_data.pop('peptide_list', '')
     input_sequence_fasta_uri = input_data.pop('input_sequence_fasta_uri', '')
     alleles = input_data.get('alleles').split(',')
+    # remove leading and trailing spaces from alleles
+    alleles = [allele.strip() for allele in alleles if allele.strip()]
+    # remove repeated alleles but keep the original order
+    # and print a warning if there are repeated alleles
+    if len(alleles) != len(set(alleles)):
+        print('warning: repeated alleles found, removing duplicates')
+        alleles = list(dict.fromkeys(alleles))
     predictors = input_data.get('predictors')
     allele_validator = AlleleValidator()
     if input_sequence_fasta_uri:
@@ -321,7 +330,7 @@ def split_parameters(input_data, split_inputs_dir=None):
                 else:
                     methods = (method,)
             for method in methods:
-                if method and method not in [ 'netchop', 'immunogenicity', 'cd4episcore']:
+                if method and method not in [ 'netchop', 'mhciinp', 'immunogenicity', 'cd4episcore']:
                     if method == 'basic_processing':
                         # TODO: run validation for its mhc_binding_method for basic_processing
                         binding_method = predictor['mhc_binding_method']
@@ -351,10 +360,10 @@ def split_parameters(input_data, split_inputs_dir=None):
         for peptide_file_path, peptide_length in peptide_file_path_length_pairs:
             for data_unit in output_data:
                 # do nothing for netchop/netctl/netctlpan here
-                if 'method' in data_unit['predictors'][0] and data_unit['predictors'][0]['method'] in ['netchop', 'netctl', 'netctlpan', 'basic_processing']:
+                if 'method' in data_unit['predictors'][0] and data_unit['predictors'][0]['method'] in ['netchop','mhciinp', 'netctl', 'netctlpan', 'basic_processing']:
                     continue
                 # do nothing for mhcnp too
-                if 'method' in data_unit['predictors'][0] and data_unit['predictors'][0]['type'] == 'mhcnp':
+                if 'method' in data_unit['predictors'][0] and data_unit['predictors'][0]['type'] == 'mhciinp':
                     continue
                 # TODO: update this after immunogenicity is added to allele_validator
                 # TODO: discuss how to deal with basic_processing if some lengths work but some do not
@@ -380,7 +389,7 @@ def split_parameters(input_data, split_inputs_dir=None):
                     if netchop_job_number > 1:
                         continue
                 # skip basic_processing/netchop/netctl/netctlpan if peptide_length_range is None (length asis means the input sequences are peptide_list)
-                if (data_unit['predictors'][0]['type'] == 'mhcnp' or 'method' in data_unit['predictors'][0] and data_unit['predictors'][0]['method'] in ['netchop', 'netctl', 'netctlpan', 'basic_processing']) and data_unit['peptide_length_range']:
+                if (data_unit['predictors'][0]['type'] == 'mhciinp' or 'method' in data_unit['predictors'][0] and data_unit['predictors'][0]['method'] in ['mhciinp', 'netchop', 'netctl', 'netctlpan', 'basic_processing']) and data_unit['peptide_length_range']:
                     # split with single length for basic_processing
                     if data_unit['predictors'][0]['method'] == 'basic_processing':
                         for length in range(peptide_length_range[0], peptide_length_range[1]+1):
