@@ -100,7 +100,8 @@ class Prediction:
             "binding\tNN_align (NetMHCII) *\t2.3\n"
             "binding\tCombinatorial library\t1.0\n"
             "binding\tSturniolo\t1.0\n"
-            "Immunogencity\CD4Episcore\t1.0\n"
+            "immunogencity\CD4Episcore\t1.0\n"
+            "processing\tMHCII-NP\t1.0\n"
         )
         print(version_info)
 
